@@ -9,15 +9,15 @@
 
 ## Configuration
 # Commands
-$LYNX = "NO";
+$LYNX = "/usr/bin/lynx";
 #$SED = "/usr/bin/sed";
 $GREP = "/usr/bin/grep";
 $RECODE = "NO"; #"/usr/bin/recode"; -- dont use recode, it is not widely available
 # Directories
-$BANKDATADIR="${pkgdatadir}";
 $prefix="/usr/local";
 $datadir="${prefix}/share";
 $pkgdatadir="$datadir/ktoblzcheck";
+$BANKDATADIR="${pkgdatadir}";
 
 ## Sanity checks
 die "lynx is not available on your system, or was not available on the system where the installed rpm was built. This tool requires lynx. If you have it installed, then edit the script and set the variable LYNX to the full path to lynx. Aborting for now."
