@@ -1447,6 +1447,21 @@ AccountNumberCheck::Result method_C7(const int *account, int *weight) {
     return method_06(account,weight);				// variant 2
 }
 
+// new methods C8 and C9 valid from June 6th, 2008, checked with Bundesbank-Testnumbers
+AccountNumberCheck::Result method_C8(const int *account, int *weight) {
+    if (AccountNumberCheck::OK == method_00(account,weight) )	// variant 1
+	return AccountNumberCheck::OK;
+    if (AccountNumberCheck::OK == method_04(account,weight) )	// variant 2
+	return AccountNumberCheck::OK;
+    return method_07(account,weight);				// variant 3
+}
+
+AccountNumberCheck::Result method_C9(const int *account, int *weight) {
+    if (AccountNumberCheck::OK == method_00(account,weight) )	// variant 1
+	return AccountNumberCheck::OK;
+    return method_07(account,weight);				// variant 2
+}
+
 struct method_func_s {
     const char *str;
     AccountNumberCheck::MethodFunc func;
@@ -1576,6 +1591,8 @@ const struct method_func_s cb_funcs[] = {
   { "C5", method_C5},
   { "C6", method_C6},
   { "C7", method_C7},
+  { "C8", method_C8},
+  { "C9", method_C9},
   { 0, 0} // Important: The array has to end with the {0,0} entry,
 	  // otherwise initMethodMap() will runaway and crash!
 };
